@@ -21,7 +21,9 @@ from locust.env import Environment
 import locust, logging
 from locust.log import greenlet_exception_logger
 from locust.user.inspectuser import print_task_ratio
-from .common import constant, config, common, robot
+from .common import constant, config, common
+from .tool import yapi
+from autoTestScheme.configuration import robot
 from .common.logger import logger
 from . import conf
 
@@ -79,6 +81,7 @@ class Run(object):
         self.uuid_list = []
         self.data_folder = None
         self.api_data = []
+        self.result_folder = None
 
     def register_tags(self, tags: dict):
         """
@@ -89,25 +92,6 @@ class Run(object):
         for key, value in tags.items():
             self.register_tag(key, value)
 
-    def register_tag(self, key, value):
-        """
-        注册标签
-        """
-        conf.settings.run.tag_list[key] = value
-
-    def debug(self, tags=None, case='all', env='dev', process_num=1):
-        """
-        调试（注意，需要再用例的tags列表内添加debug标签）
-        :param tags: 标签列表，为空时运行所有标签
-        :param case: 执行指定的用例，all指所有用例
-        :param env: 对应环境
-        :param process_num:并行数
-        :return:
-        """
-        if tags is None:
-            tags = conf.settings.run.tag_list.keys()
-        self.run(tags, case, True, env, process_num)
-
     def set_logger(self, level="DEBUG", log_file_level="DEBUG", is_allure=True, logger_folder_name='logs',
                    logger_start_str='run'):
         """
@@ -122,10 +106,8 @@ class Run(object):
             os.makedirs(log_folder)
         log_path = os.path.join(log_folder, logger_start_str + '_{time}.log')
         logger.add(log_path, level=log_file_level, rotation="200 MB")
-        # if is_allure is True:
-        #     logger.add(PropogateHandler(), level=level, format="{time:YYYY-MM-DD at HH:mm:ss} | {message}")
-        logger.info('123')
-        print(log_path)
+        if is_allure is True:
+            logger.add(PropogateHandler(), level=level, format="{time:YYYY-MM-DD at HH:mm:ss} | {message}")
 
     def load_case(self, folder_name):
         """
@@ -168,11 +150,24 @@ class Run(object):
         gevent.spawn(stats_history, runner)
         main_greenlet.join()
 
+    def get_env_name(self):
+        current_env = conf.settings.current_env
+        tag_name_list = conf.settings.run.get('tag_name_list', None)
+        if tag_name_list is None or current_env not in tag_name_list:
+            if conf.settings.exists('name'):
+                return conf.settings.name
+            else:
+                return current_env
+        else:
+            return conf.settings.run.tag_name_list[current_env]
+
     def run(self):
         self.init_dir()
-        logger.info("相关参数:{},{},{},{},{}".format(conf.settings.run.test_tags, conf.settings.run.test_case,
-                                                 conf.settings.run.is_debug, conf.settings.run.name,
-                                                 conf.settings.run.process_num))
+        tag_name = ';'.join([conf.settings.run.tag_env_list[i] for i in conf.settings.run.test_tags])
+        logger.info('开始使用 {} 个进程 {} {}(标签:{})的 {} 用例'.format(conf.settings.run.process_num,
+                                                       '运行' if conf.settings.run.is_debug is False else '调试'
+                                                        , self.get_env_name(), tag_name,
+                                                       conf.settings.run.test_case))
         logger.info('开始收集测试用例。。。。。')
         group, surplus_data = self.get_group_data()
         group_length = len(group)
@@ -396,14 +391,21 @@ class Run(object):
                             continue
 
                         for tag in list(set(conf.settings.run.test_tags).intersection(tags)):
-                            if i.get('id') is None:
-                                i['id'] = str(uuid.uuid4())
-                            i['tag'] = tag
-                            i['untag'] = 'psbc' if tag == 'antb' else 'antb'
-                            if tag not in list(self.all_data_by_channel_id.keys()):
-                                self.all_data_by_channel_id[tag] = {}
-                            self.all_data_by_channel_id[tag][i['id']] = copy.deepcopy(i)
-                            self.all_data.append(copy.deepcopy(i))
+                            subTags = i.get('subTags', ['default'])
+                            is_sub = True
+                            if isinstance(subTags, list) is False:
+                                subTags = ['default']
+                                is_sub = False
+                            for subTag in subTags:
+                                if i.get('id') is None:
+                                    i['id'] = str(uuid.uuid4())
+                                i['tag'] = tag
+                                i['subTag'] = subTag
+                                i['untag'] = 'uninfo' if tag == 'info' else 'info'
+                                if tag not in list(self.all_data_by_channel_id.keys()):
+                                    self.all_data_by_channel_id[tag] = {}
+                                self.all_data_by_channel_id[tag][i['id']] = copy.deepcopy(i)
+                                self.all_data.append(copy.deepcopy(i))
         self.replace_base_data()
 
     def replace_base_data(self):
@@ -472,9 +474,9 @@ class Run(object):
 
     def get_env(self):
         _list = []
-        _list.append(['环境:', conf.settings.run.name])
-        tags_name = ';'.join([conf.settings.run.tag_list[i] for i in conf.settings.run.test_tags])
-        _list.append(['标签:', tags_name])
+        _list.append(['环境:', self.get_env_name()])
+        tag_name = ';'.join([conf.settings.run.tag_name_list[i] for i in conf.settings.run.test_tags])
+        _list.append(['标签:', tag_name])
         _list.append(['执行用例:', conf.settings.run.test_case])
         _list.append(['并行数:', conf.settings.run.process_num])
         return _list
@@ -502,24 +504,27 @@ class Run(object):
         except Exception as e:
             logger.error(traceback.format_exc())
 
-    def get_result(self, allure_path):
-        self.check_and_create_by_dir(constant.TMP_RESULT_FOLDER)
-        command = '{} generate {} -c -o {}'.format(allure_path, constant.TMP_REPORT_DIR, constant.TMP_RESULT_FOLDER)
-        os.system(command)
-        result_path = os.path.join(constant.TMP_RESULT_FOLDER, 'widgets', 'summary.json')
+    def get_result(self):
+        if self.result_folder is None or os.path.exists(self.result_folder) is False:
+            self.check_and_create_by_dir(constant.TMP_RESULT_FOLDER)
+            command = '{} generate {} -c -o {}'.format(constant.ALLURE_PATH, constant.TMP_REPORT_DIR, constant.TMP_RESULT_FOLDER)
+            os.system(command)
+            result_path = os.path.join(constant.TMP_RESULT_FOLDER, 'widgets', 'summary.json')
+        else:
+            result_path = os.path.join(self.result_folder, 'widgets', 'summary.json')
         _config = config.Json(result_path)
         statistic = _config.get('statistic')
         _time = _config.get('time')
         return statistic, _time
 
-    def get_report(self, result_folder):
+    def get_report(self,*result_folder):
         """
         生成allure报告
         :param result_folder:报告地址文件名
         :return:
         """
-        result_folder = os.path.join(constant.BASE_DIR, result_folder)
-        command = '{} generate {} -c -o {}'.format(constant.ALLURE_PATH, constant.TMP_REPORT_DIR, result_folder)
+        self.result_folder = os.path.join(constant.BASE_DIR, *result_folder)
+        command = '{} generate {} -c -o {}'.format(constant.ALLURE_PATH, constant.TMP_REPORT_DIR, self.result_folder)
         logger.info(command)
         self.update_environment(constant.TMP_REPORT_DIR)
         logger.info(subprocess.call(command, shell=True))
@@ -527,18 +532,41 @@ class Run(object):
     def send_report_by_dingtalk(self):
         ...
 
-    def send_report_by_feishu(self, allure_path, access_token, secret, link, id=None):
-        statistic, _time = self.get_result(allure_path)
+    def convert_time(self, _time):
+        result = ""
+        if _time < 1000:
+            return " {}毫秒 ".format(_time)
+        else:
+            _time = int(_time/1000)
+        if _time > 3600:
+            result += "{} 小时 ".format(_time // 3600)
+            _time = _time % 3600
+        if _time > 60:
+            result += "{} 分钟 ".format(_time // 60)
+            _time = _time % 60
+        if _time != 0:
+            result += "{} 秒".format(_time)
+        return result
+
+    def send_report_by_feishu(self, link, title=None, is_at_all=False):
+        statistic, _time = self.get_result()
         logger.error(statistic)
         logger.error(_time)
-        created_at = self.unix_by_datetime(_time.get('start'))
-        if id is not None:
-            title = '接口测试报告(id:{})'.format(id)
-        else:
+        created_at = self.unix_by_datetime(int(_time.get('start')/1000))
+        duration = self.convert_time(_time.get('duration'))
+        if title is None:
             title = '接口测试报告'
-        response = robot.Robot().execute_robot('feishu_report', access_token, secret, title, created_at,
-                                               self.get_env(), {}, statistic, link)
-        logger.info(response)
+        if conf.settings.exists('robot'):
+            robot = conf.settings.robot
+            robot_type = robot.get('type', 'feishu')
+            robot_func = robot.get('func', 'send_lark_report')
+            if robot_type == "feishu":
+                client = conf.settings.feishu
+            if robot_func == 'send_lark_report':
+                response = client.send_lark_report(title, created_at, duration, self.get_env(), statistic, link, is_at_all)
+                logger.info(response.text)
+        else:
+            logger.error('请配置robot参数')
 
     def send_feishu(self, access_token, secret, title, text):
         response = robot.Robot().send_feishu(access_token, secret, title, text)
@@ -547,6 +575,9 @@ class Run(object):
     def unix_by_datetime(self, unix_time):
         return datetime.datetime.fromtimestamp(int(float(str(unix_time)[:10]))).strftime("%Y-%m-%d %H:%M:%S")
 
+    def load_yapi(self, name):
+        yapi.Yapi(name).load_yapi()
+
 
 if __name__ == "__main__":
     run = Run()
